From 8a5ea07f30cc71ecc413fad0713facff72f77472 Mon Sep 17 00:00:00 2001
From: Jeremy Huddleston <jeremyhu@apple.com>
Date: Tue, 18 Oct 2011 23:21:33 -0700
Subject: [PATCH 7/9] Build fix for ABI Version 12

ABI Version 12 removes support for multiple PCI domains.  If you need to
use this driver on a system with more than one PCI domain, you should
either port this driver to using libpciaccess directly or stick with an
older server.

Signed-off-by: Jeremy Huddleston <jeremyhu@apple.com>
---
 src/ct_driver.c |    5 +++++
 src/ct_driver.h |    4 ++--
 2 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/src/ct_driver.c b/src/ct_driver.c
index e6538c6..a2e5c94 100644
--- a/src/ct_driver.c
+++ b/src/ct_driver.c
@@ -1446,7 +1446,12 @@ chipsPreInitHiQV(ScrnInfoPtr pScrn, int flags)
 
     hwp = VGAHWPTR(pScrn);
     vgaHWGetIOBase(hwp);
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 12
     cPtr->PIOBase = hwp->PIOOffset;
+#else
+    cPtr->PIOBase = 0;
+#endif
+
     /*
      * Must allow ensure that storage for the 2nd set of vga registers is
      * allocated for dual channel cards
diff --git a/src/ct_driver.h b/src/ct_driver.h
index 39eeb6e..9033867 100644
--- a/src/ct_driver.h
+++ b/src/ct_driver.h
@@ -276,8 +276,8 @@ typedef struct _CHIPSRec {
 #endif
     int			Chipset;
     EntityInfoPtr       pEnt;
-    IOADDRESS		PIOBase;
-    CARD32		IOAddress;
+    unsigned long	PIOBase;
+    unsigned long	IOAddress;
     unsigned long	FbAddress;
     unsigned int	IOBase;
     unsigned char *	FbBase;
-- 
1.7.9.4

